@@ -89,7 +89,7 @@ def check_simple_annotations_match(annotations1, data, ignorecase=True):
 
 # check if annotations match with fuzz ratio
 def check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=True, min_score=DEFAULT_FUZZ_MIN_SCORE,
-                                       mode='ratio'):
+                                       mode='ratio', method='default'):
 
     if mode == 'ratio':
         score_func = fuzz.ratio
@@ -123,21 +123,33 @@ def check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=True, min_
 
     correct_count = 0
 
+    all_scores = []
+
     for a, b in annotations1_copy:
 
         valid = [el[1] for el in annotations2_copy if el[0] == a]
 
         if not bool(valid):
+            logging.warning("valid list is empty for a={0}, this should not happen!".format(a))
             continue
 
         scores = [score_func(b, el) for el in valid]
 
         max_score = max(scores)
 
+        all_scores.append(max_score)
+
         if max_score >= min_score:
             correct_count += 1
 
-    return correct_count == len(annotations1)
+    if method == 'default':
+        return correct_count == len(annotations1)
+
+    elif method == 'avg':
+        return sum(all_scores) / len(all_scores) > min_score
+
+    else:
+        raise NotImplementedError("Method {0} not implemented".format(method))
 
 
 # wrapper for check_fuzz_ratio_annotations_match with min_score=90
@@ -200,6 +212,69 @@ def check_fuzz_partial_ratio_reversed_annotations_match_70(annotations1, data, i
                                               mode='partial_ratio_reversed')
 
 
+# wrapper for check_fuzz_ratio_annotations_match with min_score=90 and average method
+def check_fuzz_ratio_annotations_match_avg_90(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=90, mode='ratio',
+                                              method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=80 and average method
+def check_fuzz_ratio_annotations_match_avg_80(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=80, mode='ratio',
+                                              method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=70 and average method
+def check_fuzz_ratio_annotations_match_avg_70(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=70, mode='ratio',
+                                              method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=90 and mode='partial_ratio' and average method
+def check_fuzz_partial_ratio_annotations_match_avg_90(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=90,
+                                              mode='partial_ratio', method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=80 and mode='partial_ratio' and average method
+def check_fuzz_partial_ratio_annotations_match_avg_80(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=80,
+                                              mode='partial_ratio', method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=70 and mode='partial_ratio' and average method
+def check_fuzz_partial_ratio_annotations_match_avg_70(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=70,
+                                              mode='partial_ratio', method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=90 and mode='partial_ratio_reversed' and average method
+def check_fuzz_partial_ratio_reversed_annotations_match_avg_90(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=90,
+                                              mode='partial_ratio_reversed', method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=80 and mode='partial_ratio' and average method
+def check_fuzz_partial_ratio_reversed_annotations_match_avg_80(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=80,
+                                              mode='partial_ratio_reversed', method='avg')
+
+
+# wrapper for check_fuzz_ratio_annotations_match with min_score=70 and mode='partial_ratio' and average method
+def check_fuzz_partial_ratio_reversed_annotations_match_avg_70(annotations1, data, ignorecase=True):
+
+    return check_fuzz_ratio_annotations_match(annotations1, data, ignorecase=ignorecase, min_score=70,
+                                              mode='partial_ratio_reversed', method='avg')
+
+
 # check if annotations match exactly apart from one element
 def check_simple_annotations_match_but_one(annotations1, data, ignorecase=True):
 
@@ -376,7 +451,16 @@ def compute_metrics(test_metrics=None, filename=METRICS_FILENAME, interactive=Fa
         check_fuzz_partial_ratio_annotations_match_90,
         check_fuzz_partial_ratio_reversed_annotations_match_70,
         check_fuzz_partial_ratio_reversed_annotations_match_80,
-        check_fuzz_partial_ratio_reversed_annotations_match_90
+        check_fuzz_partial_ratio_reversed_annotations_match_90,
+        check_fuzz_ratio_annotations_match_avg_70,
+        check_fuzz_ratio_annotations_match_avg_80,
+        check_fuzz_ratio_annotations_match_avg_90,
+        check_fuzz_partial_ratio_annotations_match_avg_70,
+        check_fuzz_partial_ratio_annotations_match_avg_80,
+        check_fuzz_partial_ratio_annotations_match_avg_90,
+        check_fuzz_partial_ratio_reversed_annotations_match_avg_70,
+        check_fuzz_partial_ratio_reversed_annotations_match_avg_80,
+        check_fuzz_partial_ratio_reversed_annotations_match_avg_90
     ]
 
     res_dict = {func.__name__: [] for func in metric_functions}
@@ -426,18 +510,23 @@ def compute_metrics(test_metrics=None, filename=METRICS_FILENAME, interactive=Fa
 
 
 # create metrics plot
-def create_metrics_plot(metrics_dict):
+def create_metrics_plot(metrics_dict, filename='ocr_test_metrics.png'):
 
-    plt.figure(figsize=(8.4, 4.8))
+    plt.figure(figsize=(8.4, 9))
 
-    plt.barh(range(len(metrics_dict)), metrics_dict.values())
+    labels = [str(round(v, 2)) + '%' for v in metrics_dict.values()]
+
+    c = plt.barh(range(len(metrics_dict)), metrics_dict.values())
+
+    plt.bar_label(c, labels)
 
     plt.yticks(range(len(metrics_dict)), metrics_dict.keys())
 
     plt.xlabel('Percentage')
     plt.ylabel('Metric')
+    plt.xlim(right=120)
 
     plt.tight_layout()
 
-    path = os.path.join(get_root_path(), 'artifacts', 'ocr_test_metrics.png')
+    path = os.path.join(get_root_path(), 'artifacts', filename)
     plt.savefig(path)
